#!/bin/bash
set -e

# Colors for output
RED='\033[0;31m'
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
NC='\033[0m'

# Configuration
REGISTRY="git.nixc.us"
IMAGE_NAME="postgre-tls"
TAG_UNSTABLE="unstable"
TAG_STABLE="stable"

echo -e "${GREEN}[Postgre-TLS] Building and pushing Docker images...${NC}"

# Build the image
echo -e "${YELLOW}[Postgre-TLS] Building Docker image...${NC}"
docker build -t ${REGISTRY}/${IMAGE_NAME}:${TAG_UNSTABLE} .

# Tag for stable if requested
if [ "$1" == "stable" ]; then
    echo -e "${YELLOW}[Postgre-TLS] Tagging as stable...${NC}"
    docker tag ${REGISTRY}/${IMAGE_NAME}:${TAG_UNSTABLE} ${REGISTRY}/${IMAGE_NAME}:${TAG_STABLE}
fi

# Push unstable
echo -e "${YELLOW}[Postgre-TLS] Pushing unstable image...${NC}"
docker push ${REGISTRY}/${IMAGE_NAME}:${TAG_UNSTABLE}

# Push stable if tagged
if [ "$1" == "stable" ]; then
    echo -e "${YELLOW}[Postgre-TLS] Pushing stable image...${NC}"
    docker push ${REGISTRY}/${IMAGE_NAME}:${TAG_STABLE}
fi

echo -e "${GREEN}[Postgre-TLS] Docker images built and pushed successfully!${NC}"
echo -e "${YELLOW}[Postgre-TLS] Available images:${NC}"
echo "- ${REGISTRY}/${IMAGE_NAME}:${TAG_UNSTABLE}"
if [ "$1" == "stable" ]; then
    echo "- ${REGISTRY}/${IMAGE_NAME}:${TAG_STABLE}"
fi 